@@ -164,6 +164,17 @@ void V8Context::set(const char* name, SV* value)
     pl_stats_stop(aTHX_ this, &perf, "set");
 }
 
+void V8Context::remove(const char* name)
+{
+    ENTER_SCOPE;
+    set_up();
+
+    Perf perf;
+    pl_stats_start(aTHX_ this, &perf);
+    pl_del_global_or_property(aTHX_ this, name);
+    pl_stats_stop(aTHX_ this, &perf, "remove");
+}
+
 SV* V8Context::eval(const char* code, const char* file)
 {
     ENTER_SCOPE;
@@ -173,18 +184,6 @@ SV* V8Context::eval(const char* code, const char* file)
     return pl_eval(aTHX_ this, code, file);
 }
 
-SV* V8Context::dispatch_function_in_event_loop(const char* func)
-{
-    ENTER_SCOPE;
-    set_up();
-
-    Perf perf;
-    pl_stats_start(aTHX_ this, &perf);
-    SV* ret = pl_run_function_in_event_loop(aTHX_ this, func);
-    pl_stats_stop(aTHX_ this, &perf, "dispatch");
-    return ret;
-}
-
 SV* V8Context::global_objects()
 {
     ENTER_SCOPE;
